clc
clear all

%% Input the parameters for the selected vessel
%Ship Category [CAC 3;CAC 4; Type A;Type B;Type C;Type D;Type E;]
vessel='Type A';
%Operational power [W]
Pe = 11*1000000;
%Design speed [knot]
V = 16;
%Length between perpendiculars [m]
L = 150;
%Breadth [m]
B = 28.5;
%Draft [m]
D = 10.5;

%% Load Data
rcp = '45';  % 45 or 85
% Sea Ice Concentration [nlat nlon ntime]
sic = load('sic_historical_mean_data.mat').data_mean;

% Sea Ice Thickness [nlat nlon ntime]
sit = load('sit_historical_mean_data.mat').data_mean;

% Sea Fog Frequency [nlat nlon ntime]
ff=load('ff_data.mat').ff_grid_value;

%ETOPO1 Topographic [nlat nlon]
terrain = load('terrain.mat').terrain; 


ntimes=size(sit,3);
%% Derive speed raster

speed = zeros(size(sit));

for i=1:ntimes
    
    sic_tmp = sic(:,:,i);
    sit_tmp = sit(:,:,i);
    ff_tmp = ff(:,:,i);
    
    
    % IN (Ice Numeral)
    % Based on Arctic Ice Regime Shipping System (AIRSS)
    % https://tc.canada.ca/en/marine-transportation/marine-safety/tp-12259e-arctic-ice-regime-shipping-system-airss-standard
    IN = AIRSS(sic_tmp,sit_tmp,vessel);
    
    
    % Speed raster for container ship (Methods)
    speed_tmp = SPEED_RASTER(sic_tmp,sit_tmp,Pe,V,L,D,B);

  
    % Influence of sea fog by deceleration coefficient (ζ) of fog frequency.
    % NOTE: The difference between Route-I and Route-F is whether to run this step.
    speed_tmp = FF(speed_tmp,ff_tmp);

    
    % Remove the position of land , shallow water and negative IN
    speed_tmp(find(terrain > -D)) = 0;
    speed_tmp(find(IN<0)) = 0;
    
   
    speed(:,:,i) = speed_tmp;
end

%% Save speed raster for R
%Route-I
savename=strcat('\speed_raster\',vessel,'\',rcp,'\','speed_raster.mat');
%Route-F
savename=strcat(UP,'\speed_raster_fog\',vessel,'\',rcp,'\','speed_raster.mat');

save(savename,'speed','-v6');

